@@ -1,4 +1,4 @@
-tm1_connection <- function(adminhost = "", httpport = "", username = "", password = "", namespace="", ssl=FALSE) {
+tm1_connection <- function(adminhost = "", httpport = "", username = "", password = "", namespace="", ssl=TRUE) {
 
   tm1_adminhost <- adminhost
   tm1_httpport <- httpport
@@ -17,11 +17,11 @@ tm1_connection <- function(adminhost = "", httpport = "", username = "", passwor
 
   tm1_auth_key <- paste(auth_type, jsonlite::base64_enc(usernamepwd), sep=" ")
 
-  httr::set_config(httr::config(ssl_verifypeer = ssl))
-  httr::set_config(httr::config(ssl_verifyhost = ssl))
+  httr::set_config(httr::config(ssl_verifypeer = FALSE))
+  httr::set_config(httr::config(ssl_verifyhost = FALSE))
 
 
-  tm1_connect_object <- list(adminhost=c(tm1_adminhost), port=c(tm1_httpport), key=c(tm1_auth_key) )
+  tm1_connect_object <- list(adminhost=c(tm1_adminhost), port=c(tm1_httpport), key=c(tm1_auth_key),  ssl=c(ssl))
 
   tm1_get_config(tm1_connect_object)
 
